# VideoInfo

VideoInfo è una libreria Python progettata per facilitare l'estrazione di metadati e informazioni da file video. Utilizzando potenti strumenti come FFmpeg e OpenCV, VideoInfo permette agli sviluppatori e agli appassionati di multimedia di accedere facilmente a una vasta gamma di dati video, tra cui bit rate, frame rate, codec, e molto altro.

## Caratteristiche

- Estrazione di metadati dettagliati dai file video.
- Generazione di miniature dai frame video.
- Supporto per diversi formati video.
- Interfacce ben definite per facilitare l'estensibilità e la manutenzione del codice.
- Facilità di integrazione in progetti esistenti.

## Installazione

Per installare VideoInfo, è sufficiente eseguire il seguente comando:

```bash
pip install gh-video-scope
```